/*
 * variables_conditioning.js
 * -------------------------
 * This file is automatically generated.
 * PLEASE DO NOT CHANGE unless you know what are you doing
 */

/*
 * Nota: le variabili dei sensori, allo stato attuale del firmware, hanno queste unità di misura:
 *
 *   * temperatura: decimi di grado Celsius
 *   * luminosità:  (da definire)
 *   * corrente:    decimi di Ampère
 *
 */
var BUS_DATA_CONDITIONING = {
  "temperature": {
    "read": function(v)  { return v / 10; },
    "write": function(v) { return Math.round(v * 10); }           // deve inviare valori interi
  },
  "luminosity": {
    "read": function(v)  { return v; },
    "write": function(v) { return v; }
  },
  "current": {
    "read": function(v)  { return v / 10; },
    "write": function(v) { return Math.round(v * 10); }                  // deve inviare valori interi
  },
  "rgb": {
    "read": function(v)  { return [v[0].value, v[1].value, v[2].value]; },
    "write": function(v) { return v; /*placeHolder*/ }
  }
};

var ALARMS_CONDITIONING = {
  "ok_alarm": {
    "read": function(v)  { if (_.isUndefined(v)) { return ""; } return (v ? 'OK' : 'alarm'); },
    "class": function(v) { if (_.isUndefined(v)) { return ""; } return (v ? 'ok' : 'error'); }
  }
};

/*
 * Funzioni di conversione per le unità di misura supportate
 */
var MEASURES_CONVERSION = {
  // unità di misura del bus
  "temperature_read_unit": "celsius",
  "current_read_unit": "ampere",
  "luminosity_read_unit": "lux",

  // il simbolo è separato con uno spazio dal suo valore
  // se presente il simolo, il valore ritornato sarà una String, altrimenti un Number
  "precision_and_symbol": function(value, symbol, precision, appendSymbol) {
    if (!_.isUndefined(precision) && _.isInteger(precision)) {
      value = Number(value.toFixed(precision));
    }
    if (!_.isUndefined(appendSymbol) && appendSymbol === true) {
      value += ' ' + symbol;
    }
    return value;
  },

  "celsius_to_fahrenheit": function(value, precision, appendSymbol) {
    var retVal = (value * 1.8) + 32;
    return this.precision_and_symbol(retVal, '°F', precision, appendSymbol);
  },

  "fahrenheit_to_celsius": function(value, precision, appendSymbol) {
    var retVal = (value - 32) / 1.8;
    return this.precision_and_symbol(retVal, '°C', precision, appendSymbol);
  },

  "celsius_to_celsius": function(value, precision, appendSymbol) {
    var retVal = value;
    return this.precision_and_symbol(retVal, '°C', precision, appendSymbol);
  },

  "ampere_to_kilowatt": function(value, precision, appendSymbol) {
    var retVal = value * app.conf.voltage / 1000;
    return this.precision_and_symbol(retVal, 'kW', precision, appendSymbol);
  },

  "kilowatt_to_ampere": function(value, precision, appendSymbol) {
    var retVal = value / app.conf.voltage * 1000;
    return this.precision_and_symbol(retVal, 'A', precision, appendSymbol);
  },

  "ampere_to_ampere": function(value, precision, appendSymbol) {
    var retVal = value;
    return this.precision_and_symbol(retVal, 'A', precision, appendSymbol);
  },

  "lux_to_lux": function(value, precision, appendSymbol) {
    var retVal = value;
    return this.precision_and_symbol(retVal, 'lx', precision, appendSymbol);
  },

  "conversionFunctionMaker": function(fromUnit, toUnit, precision, appendSymbol) {
    var closeThis = this;
    return function(v) {
      var fnName = fromUnit + '_to_' + toUnit;
      return closeThis[fnName](v, precision, appendSymbol);
    };
  }
};

/*
 * Condizionamento delle variabili in lettura
 */
var VARS_READ_CONDITIONING = {
// [VARS_READ_CONDITIONING]  
};